#!/home/steffen/bin/perl
# $Id: daily-tom.pl,v 1.13 2010/10/07 19:26:18 steffen Exp steffen $
use strict;
use warnings;
use WWW::Mechanize;
use LWP::ConnCache;
use Cwd 'realpath';
use Getopt::Long qw(:config posix_default bundling);

my $base  = "$ENV{HOME}/Digikam/TOM";
$base = '.' if ! -d $base;
my $start = 0;
my $end   = 400;

sub usage {
	print STDERR <<USAGE;
Get current and older TOM comics from taz.de and puts the into basedir
named by date. Prints file names to stdout.
Usage: $0 [options]
Options: 
 -h|--help          this screen
 -B|--basedir dir   dir where to put the images ($base)
 -S|--start S       how many dates back from now to start ($start)
 -E|--end E         how many dates back from now end ($end)
USAGE
	exit(2)
}

GetOptions(
	'B|base=s'  => \$base,
	'S|start=i' => \$start,
	'E|end=i'   => \$end,
	'h|help'    => \&usage,
) or usage();
-d $base or die "no basedir $base";

for( my $i = $start; $i<$end;$i++ ) {
	my $time = time() -24*3600*$i;
	my @date = localtime( $time );
	my $target = sprintf "$base/%04d%02d%02d", $date[5]+1900,$date[4]+1,$date[3];
	last if glob("$target.*");

	my $agent = WWW::Mechanize->new();
	$agent->conn_cache( LWP::ConnCache->new );

	# zum Tag http://www.taz.de/digitaz/.tom/tomdestages?day=2008/08/05
	my $url = sprintf "http://www.taz.de/digitaz/.tom/tomdestages?day=%4d/%2d/%2d",
		$date[5]+1900,$date[4]+1,$date[3];
	$agent->get( $url ) || die "kein Link $url";

	# IMG mit ALT-Tag TOM
	my $link = $agent->find_image( alt => 'TOM' )
		|| die "kein Bild mit ALT-Tag 'TOM'";
	my $url_tom = $link->url;
	$url_tom =~s{,\d+$}{,$time} || die;
	$agent->get( $url_tom );
	if ( $agent->ct !~ m{^image/(.*)} ) {
		warn "content-type: ".$agent->ct ;
		next;
	}
	$target .= ".".$1;
	open( my $fh,'>',$target) || die "open $target: $!";
	print $fh $agent->content;
	close($fh);
	print $target,"\n";
}


__END__
 vim: set ts=4 ai:

